==> monocdk.experiment-1.49.0.tar.gz: package/lib/aws-appmesh/lib/mesh.d.ts <==
import * as cdk from "../../core";
import { VirtualNode, VirtualNodeBaseProps } from './virtual-node';
import { VirtualRouter, VirtualRouterBaseProps } from './virtual-router';
import { VirtualService, VirtualServiceBaseProps } from './virtual-service';
/**
 * A utility enum defined for the egressFilter type property, the default of DROP_ALL,
 * allows traffic only to other resources inside the mesh, or API calls to amazon resources.
 *
 * @default DROP_ALL
 */
export declare enum MeshFilterType {
    /**
     * Allows all outbound traffic
     */
    ALLOW_ALL = "ALLOW_ALL",
    /**
     * Allows traffic only to other resources inside the mesh, or API calls to amazon resources
     */
    DROP_ALL = "DROP_ALL"
}
/**
 * Interface wich all Mesh based classes MUST implement
 */
export interface IMesh extends cdk.IResource {
    /**
     * The name of the AppMesh mesh
     *
     * @attribute
     */
    readonly meshName: string;
    /**
     * The Amazon Resource Name (ARN) of the AppMesh mesh
     *
     * @attribute
     */
    readonly meshArn: string;
    /**
     * Adds a VirtualRouter to the Mesh with the given id and props
     */
    addVirtualRouter(id: string, props?: VirtualRouterBaseProps): VirtualRouter;
    /**
     * Adds a VirtualService with the given id
     */
    addVirtualService(id: string, props?: VirtualServiceBaseProps): VirtualService;
    /**
     * Adds a VirtualNode to the Mesh
     */
    addVirtualNode(id: string, props?: VirtualNodeBaseProps): VirtualNode;
}
/**
 * Represents a new or imported AppMesh mesh
 */
declare abstract class MeshBase extends cdk.Resource implements IMesh {
    /**
     * The name of the AppMesh mesh
     */
    abstract readonly meshName: string;
    /**
     * The Amazon Resource Name (ARN) of the AppMesh mesh
     */
    abstract readonly meshArn: string;
    /**
     * Adds a VirtualRouter to the Mesh with the given id and props
     */
    addVirtualRouter(id: string, props?: VirtualRouterBaseProps): VirtualRouter;
    /**
     * Adds a VirtualService with the given id
     */
    addVirtualService(id: string, props?: VirtualServiceBaseProps): VirtualService;
    /**
     * Adds a VirtualNode to the Mesh
     */
    addVirtualNode(id: string, props?: VirtualNodeBaseProps): VirtualNode;
}
/**
 * The set of properties used when creating a Mesh
 */
export interface MeshProps {
    /**
     * The name of the Mesh being defined
     *
     * @default - A name is autmoatically generated
     */
    readonly meshName?: string;
    /**
     * Egress filter to be applied to the Mesh
     *
     * @default DROP_ALL
     */
    readonly egressFilter?: MeshFilterType;
}
/**
 * Define a new AppMesh mesh
 *
 * @see https://docs.aws.amazon.com/app-mesh/latest/userguide/meshes.html
 */
export declare class Mesh extends MeshBase {
    /**
     * Import an existing mesh by arn
     */
    static fromMeshArn(scope: cdk.Construct, id: string, meshArn: string): IMesh;
    /**
     * Import an existing mesh by name
     */
    static fromMeshName(scope: cdk.Construct, id: string, meshName: string): IMesh;
    /**
     * The name of the AppMesh mesh
     */
    readonly meshName: string;
    /**
     * The Amazon Resource Name (ARN) of the AppMesh mesh
     */
    readonly meshArn: string;
    constructor(scope: cdk.Construct, id: string, props?: MeshProps);
}
export {};

==> monocdk.experiment-1.65.0.tar.gz: package/lib/aws-appmesh/lib/mesh.d.ts <==
import * as cdk from "../../core";
import { Construct } from 'constructs';
import { VirtualNode, VirtualNodeBaseProps } from './virtual-node';
import { VirtualRouter, VirtualRouterBaseProps } from './virtual-router';
import { VirtualService, VirtualServiceBaseProps } from './virtual-service';
/**
 * A utility enum defined for the egressFilter type property, the default of DROP_ALL,
 * allows traffic only to other resources inside the mesh, or API calls to amazon resources.
 *
 * @default DROP_ALL
 */
export declare enum MeshFilterType {
    /**
     * Allows all outbound traffic
     */
    ALLOW_ALL = "ALLOW_ALL",
    /**
     * Allows traffic only to other resources inside the mesh, or API calls to amazon resources
     */
    DROP_ALL = "DROP_ALL"
}
/**
 * Interface wich all Mesh based classes MUST implement
 */
export interface IMesh extends cdk.IResource {
    /**
     * The name of the AppMesh mesh
     *
     * @attribute
     */
    readonly meshName: string;
    /**
     * The Amazon Resource Name (ARN) of the AppMesh mesh
     *
     * @attribute
     */
    readonly meshArn: string;
    /**
     * Adds a VirtualRouter to the Mesh with the given id and props
     */
    addVirtualRouter(id: string, props?: VirtualRouterBaseProps): VirtualRouter;
    /**
     * Adds a VirtualService with the given id
     */
    addVirtualService(id: string, props?: VirtualServiceBaseProps): VirtualService;
    /**
     * Adds a VirtualNode to the Mesh
     */
    addVirtualNode(id: string, props?: VirtualNodeBaseProps): VirtualNode;
}
/**
 * Represents a new or imported AppMesh mesh
 */
declare abstract class MeshBase extends cdk.Resource implements IMesh {
    /**
     * The name of the AppMesh mesh
     */
    abstract readonly meshName: string;
    /**
     * The Amazon Resource Name (ARN) of the AppMesh mesh
     */
    abstract readonly meshArn: string;
    /**
     * Adds a VirtualRouter to the Mesh with the given id and props
     */
    addVirtualRouter(id: string, props?: VirtualRouterBaseProps): VirtualRouter;
    /**
     * Adds a VirtualService with the given id
     */
    addVirtualService(id: string, props?: VirtualServiceBaseProps): VirtualService;
    /**
     * Adds a VirtualNode to the Mesh
     */
    addVirtualNode(id: string, props?: VirtualNodeBaseProps): VirtualNode;
}
/**
 * The set of properties used when creating a Mesh
 */
export interface MeshProps {
    /**
     * The name of the Mesh being defined
     *
     * @default - A name is autmoatically generated
     */
    readonly meshName?: string;
    /**
     * Egress filter to be applied to the Mesh
     *
     * @default DROP_ALL
     */
    readonly egressFilter?: MeshFilterType;
}
/**
 * Define a new AppMesh mesh
 *
 * @see https://docs.aws.amazon.com/app-mesh/latest/userguide/meshes.html
 */
export declare class Mesh extends MeshBase {
    /**
     * Import an existing mesh by arn
     */
    static fromMeshArn(scope: Construct, id: string, meshArn: string): IMesh;
    /**
     * Import an existing mesh by name
     */
    static fromMeshName(scope: Construct, id: string, meshName: string): IMesh;
    /**
     * The name of the AppMesh mesh
     */
    readonly meshName: string;
    /**
     * The Amazon Resource Name (ARN) of the AppMesh mesh
     */
    readonly meshArn: string;
    constructor(scope: Construct, id: string, props?: MeshProps);
}
export {};
